@@ -482,6 +482,9 @@ def anac2019_sabotage_assigner(
     fair: bool = True,
     competitors: Sequence[Type[Agent]] = (),
     params: Sequence[Dict[str, Any]] = (),
+    dynamic_non_competitors: Optional[List[Type[Agent]]] = None,
+    dynamic_non_competitor_params: Optional[List[Dict[str, Any]]] = None,
+    exclude_competitors_from_reassignment: bool = True,
 ) -> List[List[Dict[str, Any]]]:
     config = config[0]
     competitors = list(
@@ -613,7 +616,6 @@ def anac2019_sabotage_assigner(
                     perm = copy.deepcopy(permutation)
                     shuffle(perm)
                     configs.append(_copy_config(perm, config, k, competitor, c_params))
-
     if agent_names_reveal_type:
         for config_set in configs:
             for config in config_set:
@@ -638,7 +640,6 @@ def anac2019_sabotage_assigner(
                     p["name"] = f'{name_}@{f["id"][1:]}'
                     config["manager_params"][i] = copy.deepcopy(p)
                     nxt = nxt + 1
-
     return configs
 
 
@@ -649,6 +650,9 @@ def anac2019_assigner(
     fair: bool = True,
     competitors: Sequence[Type[Agent]] = (),
     params: Sequence[Dict[str, Any]] = (),
+    dynamic_non_competitors: Optional[List[Type[Agent]]] = None,
+    dynamic_non_competitor_params: Optional[List[Dict[str, Any]]] = None,
+    exclude_competitors_from_reassignment: bool = True,
 ) -> List[List[Dict[str, Any]]]:
     config = config[0]
     competitors = list(
