@@ -7,16 +7,19 @@ from typing import Tuple
 
 from negmas import LinearUtilityFunction
 
-from scml.scml2020.components import FixedERPStrategy
 from scml.scml2020.components import (
     SupplyDrivenProductionStrategy,
     StepNegotiationManager,
     IndependentNegotiationsManager,
 )
-from .do_nothing import DoNothingAgent
 from ..components.trading import PredictionBasedTradingStrategy
+from ..components.signing import KeepOnlyGoodPrices
 
-__all__ = ["DecentralizingAgent", "IndDecentralizingAgent"]
+__all__ = [
+    "DecentralizingAgent",
+    "IndDecentralizingAgent",
+    "DecentralizingAgentWithLogging",
+]
 
 from ..world import SCML2020Agent
 
@@ -48,6 +51,7 @@ class _NegotiationCallbacks:
 
 
 class DecentralizingAgent(
+    KeepOnlyGoodPrices,
     _NegotiationCallbacks,
     StepNegotiationManager,
     PredictionBasedTradingStrategy,
@@ -57,7 +61,26 @@ class DecentralizingAgent(
     pass
 
 
+class DecentralizingAgentWithLogging(
+    KeepOnlyGoodPrices,
+    _NegotiationCallbacks,
+    StepNegotiationManager,
+    PredictionBasedTradingStrategy,
+    SupplyDrivenProductionStrategy,
+    SCML2020Agent,
+):
+    def __init__(self, *args, buying_margin=0.33, selling_margin=0.33, **kwargs):
+        super().__init__(
+            *args,
+            buying_margin=buying_margin,
+            selling_margin=selling_margin,
+            logdebug=True,
+            **kwargs
+        )
+
+
 class IndDecentralizingAgent(
+    KeepOnlyGoodPrices,
     _NegotiationCallbacks,
     IndependentNegotiationsManager,
     PredictionBasedTradingStrategy,
